# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .copilot import Copilot
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class SrcHandlersListCopilotsResponse(UncheckedBaseModel):
    data: typing.List[Copilot]
    next_cursor: typing.Optional[dt.datetime] = None
    has_more: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .workflow_run_stop_reason import WorkflowRunStopReason
import typing
from .workflow_run_state_value import WorkflowRunStateValue
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class WorkflowRun(UncheckedBaseModel):
    stop_reason: WorkflowRunStopReason
    state: typing.Optional[typing.Dict[str, typing.Optional[WorkflowRunStateValue]]] = None
    errors: typing.Optional[typing.List[str]] = None
    session_id: str
    workflow_run_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

WorkflowsRunRequestInputsValue = typing.Union[
    bool, typing.Dict[str, typing.Optional[typing.Any]], float, int, typing.List[typing.Optional[typing.Any]], str
]



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.src_handlers_get_workflow_environments_response import SrcHandlersGetWorkflowEnvironmentsResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.environment_deployment_config import EnvironmentDeploymentConfig
from ..types.src_handlers_update_workflow_environment_response import SrcHandlersUpdateWorkflowEnvironmentResponse
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class EnvironmentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersGetWorkflowEnvironmentsResponse:
        """
        List all environments for a workflow in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersGetWorkflowEnvironmentsResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.environments.list(
            workflow_id="workflow_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/environments",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersGetWorkflowEnvironmentsResponse,
                    construct_type(
                        type_=SrcHandlersGetWorkflowEnvironmentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update(
        self,
        workflow_id: str,
        environment_id: str,
        *,
        name: str,
        description: str,
        deployments: typing.Sequence[EnvironmentDeploymentConfig],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcHandlersUpdateWorkflowEnvironmentResponse:
        """
        Update deployments within a workflow environment

        Parameters
        ----------
        workflow_id : str

        environment_id : str

        name : str

        description : str

        deployments : typing.Sequence[EnvironmentDeploymentConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersUpdateWorkflowEnvironmentResponse
            Successful Response

        Examples
        --------
        from scoutos import EnvironmentDeploymentConfig, Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.environments.update(
            workflow_id="workflow_id",
            environment_id="environment_id",
            name="name",
            description="description",
            deployments=[
                EnvironmentDeploymentConfig(
                    revision_lookup="latest",
                )
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/environments/{jsonable_encoder(environment_id)}",
            method="PUT",
            json={
                "name": name,
                "description": description,
                "deployments": deployments,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersUpdateWorkflowEnvironmentResponse,
                    construct_type(
                        type_=SrcHandlersUpdateWorkflowEnvironmentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncEnvironmentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersGetWorkflowEnvironmentsResponse:
        """
        List all environments for a workflow in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersGetWorkflowEnvironmentsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environments.list(
                workflow_id="workflow_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/environments",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersGetWorkflowEnvironmentsResponse,
                    construct_type(
                        type_=SrcHandlersGetWorkflowEnvironmentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update(
        self,
        workflow_id: str,
        environment_id: str,
        *,
        name: str,
        description: str,
        deployments: typing.Sequence[EnvironmentDeploymentConfig],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcHandlersUpdateWorkflowEnvironmentResponse:
        """
        Update deployments within a workflow environment

        Parameters
        ----------
        workflow_id : str

        environment_id : str

        name : str

        description : str

        deployments : typing.Sequence[EnvironmentDeploymentConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersUpdateWorkflowEnvironmentResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout, EnvironmentDeploymentConfig

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environments.update(
                workflow_id="workflow_id",
                environment_id="environment_id",
                name="name",
                description="description",
                deployments=[
                    EnvironmentDeploymentConfig(
                        revision_lookup="latest",
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/environments/{jsonable_encoder(environment_id)}",
            method="PUT",
            json={
                "name": name,
                "description": description,
                "deployments": deployments,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersUpdateWorkflowEnvironmentResponse,
                    construct_type(
                        type_=SrcHandlersUpdateWorkflowEnvironmentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from .check_box_column import CheckBoxColumn
from .json_column import JsonColumn
from .markdown_column import MarkdownColumn
from .number_column import NumberColumn
from .select_column import SelectColumn
from .text_long_column import TextLongColumn
from .text_short_column import TextShortColumn
from .url_column import UrlColumn

TableConfigOutputSchemaItem = typing.Union[
    CheckBoxColumn, JsonColumn, MarkdownColumn, NumberColumn, SelectColumn, TextLongColumn, TextShortColumn, UrlColumn
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .actor import Actor
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class WorkflowRunStartedData(UncheckedBaseModel):
    actor: typing.Optional[Actor] = None
    workflow_id: str
    workflow_run_id: typing.Optional[str] = None
    inputs: typing.Dict[str, typing.Optional[typing.Any]]
    session_id: typing.Optional[str] = None
    state: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    workflow_config: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    price: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .user_identity import UserIdentity
from .api_key_identity import ApiKeyIdentity

IdentityDetails = typing.Union[UserIdentity, ApiKeyIdentity]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BlockRunFailedData(UncheckedBaseModel):
    workflow_id: str
    workflow_run_id: str
    block_id: typing.Optional[str] = None
    cost: typing.Optional[float] = None
    config: typing.Dict[str, typing.Optional[typing.Any]]
    message: str = pydantic.Field()
    """
    The reason why the job failed
    """

    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    state: typing.Dict[str, typing.Optional[typing.Any]]
    session_id: str
    block_type: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class MarkdownColumn(UncheckedBaseModel):
    column_id: typing.Optional[str] = None
    column_display_name: typing.Optional[str] = None
    column_type: typing.Literal["markdown"] = "markdown"
    data_type: typing.Optional[typing.Literal["string"]] = None
    hidden: typing.Optional[bool] = None
    default: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .block_input_block_config_item import BlockInputBlockConfigItem
from .dependency import Dependency
from .node_ui import NodeUi
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class BlockInput(UncheckedBaseModel):
    block_archetype_id: str
    block_config: typing.Optional[typing.List[BlockInputBlockConfigItem]] = None
    block_display_name: str
    block_id: str
    block_inputs: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    block_is_output: typing.Optional[bool] = None
    dependencies: typing.Optional[typing.List[Dependency]] = None
    input_schema: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    output_schema: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    ui: typing.Optional[NodeUi] = None
    trigger_config: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
from ..core.request_options import RequestOptions
from ..types.src_handlers_list_workflow_revisions_response import SrcHandlersListWorkflowRevisionsResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.src_handlers_promote_workflow_revision_response import SrcHandlersPromoteWorkflowRevisionResponse
from ..types.src_handlers_delete_workflow_revision_response import SrcHandlersDeleteWorkflowRevisionResponse
from ..core.client_wrapper import AsyncClientWrapper


class RevisionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersListWorkflowRevisionsResponse:
        """
        List all app revisions in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersListWorkflowRevisionsResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.revisions.list(
            workflow_id="workflow_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/revisions",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersListWorkflowRevisionsResponse,
                    construct_type(
                        type_=SrcHandlersListWorkflowRevisionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersPromoteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersPromoteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.revisions.update(
            workflow_id="workflow_id",
            revision_id="revision_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/revisions/{jsonable_encoder(revision_id)}/promote",
            method="PUT",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersPromoteWorkflowRevisionResponse,
                    construct_type(
                        type_=SrcHandlersPromoteWorkflowRevisionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersDeleteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersDeleteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.revisions.delete(
            workflow_id="workflow_id",
            revision_id="revision_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/revisions/{jsonable_encoder(revision_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersDeleteWorkflowRevisionResponse,
                    construct_type(
                        type_=SrcHandlersDeleteWorkflowRevisionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncRevisionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersListWorkflowRevisionsResponse:
        """
        List all app revisions in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersListWorkflowRevisionsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.revisions.list(
                workflow_id="workflow_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/revisions",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersListWorkflowRevisionsResponse,
                    construct_type(
                        type_=SrcHandlersListWorkflowRevisionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersPromoteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersPromoteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.revisions.update(
                workflow_id="workflow_id",
                revision_id="revision_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/revisions/{jsonable_encoder(revision_id)}/promote",
            method="PUT",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersPromoteWorkflowRevisionResponse,
                    construct_type(
                        type_=SrcHandlersPromoteWorkflowRevisionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersDeleteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersDeleteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.revisions.delete(
                workflow_id="workflow_id",
                revision_id="revision_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/workflows/{jsonable_encoder(workflow_id)}/revisions/{jsonable_encoder(revision_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SrcHandlersDeleteWorkflowRevisionResponse,
                    construct_type(
                        type_=SrcHandlersDeleteWorkflowRevisionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Actor,
    ActorType,
    ApiKeyIdentity,
    BlockConfigItemBoolean,
    BlockConfigItemJson,
    BlockConfigItemLlm,
    BlockConfigItemNumber,
    BlockConfigItemNumberDefaultValue,
    BlockConfigItemNumberMaximumValue,
    BlockConfigItemNumberMinimumValue,
    BlockConfigItemNumberValue,
    BlockConfigItemSelect,
    BlockConfigItemTextLong,
    BlockConfigItemTextLongValue,
    BlockConfigItemTextShort,
    BlockInput,
    BlockInputBlockConfigItem,
    BlockOutput,
    BlockOutputBlockConfigItem,
    BlockRunCompleted,
    BlockRunCompletedData,
    BlockRunCompletedEnvironment,
    BlockRunFailed,
    BlockRunFailedData,
    BlockRunFailedEnvironment,
    BlockRunStarted,
    BlockRunStartedData,
    BlockRunStartedEnvironment,
    BlockRunUsage,
    BlockStateUpdated,
    BlockStateUpdatedData,
    BlockStateUpdatedDataUpdateType,
    BlockStateUpdatedEnvironment,
    CheckBoxColumn,
    Collection,
    CollectionConfig,
    Copilot,
    CopilotConfig,
    CopilotConfigFabValue,
    CopilotConfigMode,
    Dependency,
    Document,
    DocumentDataValue,
    EdgeUi,
    Environment,
    EnvironmentConfig,
    EnvironmentDeploymentConfig,
    EnvironmentDeploymentConfigRevisionLookup,
    EnvironmentDeploymentDocument,
    EvalServiceHandlersCreateCollectionResponse,
    EvalServiceHandlersCreateDocumentResponse,
    EvalServiceHandlersCreateTableResponse,
    EvalServiceHandlersDeleteCollectionResponse,
    EvalServiceHandlersDeleteDocumentResponse,
    EvalServiceHandlersDeleteTableResponse,
    EvalServiceHandlersGetCollectionResponse,
    EvalServiceHandlersGetCollectionsResponse,
    EvalServiceHandlersGetDocumentResponse,
    EvalServiceHandlersGetDocumentsResponse,
    EvalServiceHandlersGetTableResponse,
    EvalServiceHandlersGetTablesResponse,
    EvalServiceHandlersUpdateCollectionResponse,
    EvalServiceHandlersUpdateDocumentResponse,
    EvalServiceHandlersUpdateTableResponse,
    EventVersion,
    HttpValidationError,
    Identity,
    IdentityDetails,
    IdentityTypes,
    JsonColumn,
    MarkdownColumn,
    Message,
    MessageChunk,
    NodeUi,
    NumberColumn,
    NumberColumnDefault,
    NumberColumnMaxValue,
    NumberColumnMinValue,
    Position,
    Prompt,
    PromptRole,
    ResponseModelUsage,
    SelectColumn,
    SelectOptionItem,
    SrcHandlersCreateCopilotResponse,
    SrcHandlersCreateWorkflowResponse,
    SrcHandlersDeleteCopilotResponse,
    SrcHandlersDeleteWorkflowResponse,
    SrcHandlersDeleteWorkflowRevisionResponse,
    SrcHandlersGetCopilotResponse,
    SrcHandlersGetWorkflowEnvironmentsResponse,
    SrcHandlersGetWorkflowResponse,
    SrcHandlersListCopilotsResponse,
    SrcHandlersListWorkflowRevisionsResponse,
    SrcHandlersListWorkflowsResponse,
    SrcHandlersPromoteWorkflowRevisionResponse,
    SrcHandlersUpdateCopilotResponse,
    SrcHandlersUpdateWorkflowEnvironmentResponse,
    SrcHandlersUpdateWorkflowResponse,
    Table,
    TableConfigInput,
    TableConfigInputSchemaItem,
    TableConfigOutput,
    TableConfigOutputSchemaItem,
    TextLongColumn,
    TextShortColumn,
    UrlColumn,
    Usage,
    UserIdentity,
    ValidationError,
    ValidationErrorLocItem,
    Workflow,
    WorkflowConfigInput,
    WorkflowConfigOutput,
    WorkflowRun,
    WorkflowRunCompleted,
    WorkflowRunCompletedData,
    WorkflowRunCompletedEnvironment,
    WorkflowRunFailed,
    WorkflowRunFailedData,
    WorkflowRunFailedEnvironment,
    WorkflowRunResponse,
    WorkflowRunStarted,
    WorkflowRunStartedData,
    WorkflowRunStartedEnvironment,
    WorkflowRunStateValue,
    WorkflowRunStopReason,
    WorkflowRunStreamResponse,
)
from .errors import UnprocessableEntityError
from . import collections, copilots, documents, environments, revisions, tables, usage, workflow_logs, workflows
from .client import AsyncScout, Scout
from .documents import (
    DocumentsCreateRequest,
    DocumentsCreateRequestItemValue,
    DocumentsCreateRequestZeroValue,
    DocumentsUpdateRequestValue,
)
from .environment import ScoutEnvironment
from .version import __version__
from .workflows import WorkflowsRunRequestInputsValue, WorkflowsRunStreamRequestInputsValue

__all__ = [
    "Actor",
    "ActorType",
    "ApiKeyIdentity",
    "AsyncScout",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "CheckBoxColumn",
    "Collection",
    "CollectionConfig",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "Dependency",
    "Document",
    "DocumentDataValue",
    "DocumentsCreateRequest",
    "DocumentsCreateRequestItemValue",
    "DocumentsCreateRequestZeroValue",
    "DocumentsUpdateRequestValue",
    "EdgeUi",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EvalServiceHandlersCreateCollectionResponse",
    "EvalServiceHandlersCreateDocumentResponse",
    "EvalServiceHandlersCreateTableResponse",
    "EvalServiceHandlersDeleteCollectionResponse",
    "EvalServiceHandlersDeleteDocumentResponse",
    "EvalServiceHandlersDeleteTableResponse",
    "EvalServiceHandlersGetCollectionResponse",
    "EvalServiceHandlersGetCollectionsResponse",
    "EvalServiceHandlersGetDocumentResponse",
    "EvalServiceHandlersGetDocumentsResponse",
    "EvalServiceHandlersGetTableResponse",
    "EvalServiceHandlersGetTablesResponse",
    "EvalServiceHandlersUpdateCollectionResponse",
    "EvalServiceHandlersUpdateDocumentResponse",
    "EvalServiceHandlersUpdateTableResponse",
    "EventVersion",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "JsonColumn",
    "MarkdownColumn",
    "Message",
    "MessageChunk",
    "NodeUi",
    "NumberColumn",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "Position",
    "Prompt",
    "PromptRole",
    "ResponseModelUsage",
    "Scout",
    "ScoutEnvironment",
    "SelectColumn",
    "SelectOptionItem",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "Table",
    "TableConfigInput",
    "TableConfigInputSchemaItem",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TextLongColumn",
    "TextShortColumn",
    "UnprocessableEntityError",
    "UrlColumn",
    "Usage",
    "UserIdentity",
    "ValidationError",
    "ValidationErrorLocItem",
    "Workflow",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
    "WorkflowsRunRequestInputsValue",
    "WorkflowsRunStreamRequestInputsValue",
    "__version__",
    "collections",
    "copilots",
    "documents",
    "environments",
    "revisions",
    "tables",
    "usage",
    "workflow_logs",
    "workflows",
]
